<?php

namespace Drupal\acquia_contenthub\EventSubscriber\CDFAttributes;

use Acquia\ContentHubClient\CDFAttribute;
use Drupal\acquia_contenthub\AcquiaContentHubEvents;
use Drupal\acquia_contenthub\Event\CDFAttributesEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Extracts user specific data for identifying duplicate and anonymous users.
 */
class UserDataCDFAttribute  implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[AcquiaContentHubEvents::POPULATE_CDF_ATTRIBUTES][] = ['onPopulateAttributes', 100];
    return $events;
  }

  /**
   * Method called on the POPULATE_CDF_ATTRIBUTES event.
   *
   * Extracts user specific data for identifying duplicate and anonymous users.
   *
   * @param \Drupal\acquia_contenthub\Event\CDFAttributesEvent $event
   *   The CDFAttributesEvent object.
   *
   * @throws \Exception
   */
  public function onPopulateAttributes(CDFAttributesEvent $event) {
    $entity = $event->getEntity();
    if ($entity->getEntityTypeId() == 'user') {
      /** @var \Drupal\user\Entity\User $entity */
      $cdf = $event->getCDF();
      $cdf->addAttribute('username', CDFAttribute::TYPE_STRING, $entity->label());
      if ($entity->isAnonymous()) {
        $cdf->addAttribute('is_anonymous', CDFAttribute::TYPE_BOOLEAN, TRUE);
      }
      else {
        $cdf->addAttribute('mail', CDFAttribute::TYPE_STRING, $entity->getEmail());
      }
    }
  }

}
