<?php

namespace Drupal\acquia_contenthub\EventSubscriber\EntityDataTamper;

use Drupal\acquia_contenthub\AcquiaContentHubEvents;
use Drupal\acquia_contenthub\Event\EntityDataTamperEvent;
use Drupal\acquia_contenthub\Event\ParseCDFEntityEvent;
use Drupal\depcalc\DependentEntityWrapper;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Replace recognized remote user with an appropriate local user.
 */
class ExistingUser implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[AcquiaContentHubEvents::ENTITY_DATA_TAMPER][] = 'onDataTamper';
    $events[AcquiaContentHubEvents::PARSE_CDF][] = ['onParseCDF', 90];

    return $events;
  }

  /**
   * Tamper with cdf data before its imported.
   *
   * @param \Drupal\acquia_contenthub\Event\EntityDataTamperEvent $event
   *   The data tamper event.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  public function onDataTamper(EntityDataTamperEvent $event) {
    $cdf = $event->getCDF();
    /**
     * @var string $uuid
     * @var \Acquia\ContentHubClient\CDF\CDFObject $object
     */
    foreach ($cdf->getEntities() as $uuid => $object) {
      $entity_type = $object->getAttribute('entity_type');
      if ($entity_type && $entity_type->getValue()['und'] == 'user') {
        $mail = $object->getAttribute('mail')->getValue()['und'];
        // We assume that existing accounts with email addresses can take this over.
        if ($account = user_load_by_mail($mail)) {
          $wrapper = new DependentEntityWrapper($account);
          $wrapper->setRemoteUuid($uuid);
          $event->getStack()->addDependency($wrapper);
        }
      }
    }
  }

  /**
   * Parses the CDF representation of Content Entities.
   */
  public function onParseCDF(ParseCDFEntityEvent $event) {
    $cdf = $event->getCDF();
    if ($cdf->getAttribute('entity_type')->getValue()['und'] != 'user') {
      // Bail early if this isn't a content entity.
      return;
    }

    $username = $cdf->getAttribute('username')->getValue()['und'];
    $mail = $cdf->getAttribute('mail')->getValue()['und'];
    if ($account = user_load_by_name($username)) {
      // If email and account match, don't do anything because the user exists.
      if ($account->mail == $mail) {
        return;
      }
      // The blank entity about to get parsed.
      /** @var \Drupal\user\Entity\User $entity */
      $entity = $event->getEntity();
      $entity->setUsername($cdf->getUuid() . ' (' . $username . ')');
      $event->setEntity($entity);
    }
  }

}
